@@ -194,6 +194,7 @@ package Net::SAML;
 *parse_cgi = *Net::SAMLc::zxid_parse_cgi;
 *new_cgi = *Net::SAMLc::zxid_new_cgi;
 *get_sid_from_cookie = *Net::SAMLc::zxid_get_sid_from_cookie;
+*alloc_ses = *Net::SAMLc::zxid_alloc_ses;
 *fetch_ses = *Net::SAMLc::zxid_fetch_ses;
 *get_ses = *Net::SAMLc::zxid_get_ses;
 *put_ses = *Net::SAMLc::zxid_put_ses;
@@ -206,6 +207,7 @@ package Net::SAML;
 *pool_to_qs = *Net::SAMLc::zxid_pool_to_qs;
 *ses_to_pool = *Net::SAMLc::zxid_ses_to_pool;
 *add_attr_to_pool = *Net::SAMLc::zxid_add_attr_to_pool;
+*add_qs_to_pool = *Net::SAMLc::zxid_add_qs_to_pool;
 *parse_mni = *Net::SAMLc::zxid_parse_mni;
 *put_user = *Net::SAMLc::zxid_put_user;
 *get_user_nameid = *Net::SAMLc::zxid_get_user_nameid;
@@ -273,6 +275,9 @@ package Net::SAML;
 *mni_do = *Net::SAMLc::zxid_mni_do;
 *mni_do_ss = *Net::SAMLc::zxid_mni_do_ss;
 *pep_az_soap = *Net::SAMLc::zxid_pep_az_soap;
+*az_cf_ses = *Net::SAMLc::zxid_az_cf_ses;
+*az_cf = *Net::SAMLc::zxid_az_cf;
+*az = *Net::SAMLc::zxid_az;
 *find_attribute = *Net::SAMLc::zxid_find_attribute;
 *mk_authn_req = *Net::SAMLc::zxid_mk_authn_req;
 *mk_art_deref = *Net::SAMLc::zxid_mk_art_deref;
@@ -305,6 +310,8 @@ package Net::SAML;
 *wsc_call = *Net::SAMLc::zxid_wsc_call;
 *new_envf = *Net::SAMLc::zxid_new_envf;
 *callf = *Net::SAMLc::zxid_callf;
+*simple_call = *Net::SAMLc::zxid_simple_call;
+*simple_callf = *Net::SAMLc::zxid_simple_callf;
 *nice_sha1 = *Net::SAMLc::zxid_nice_sha1;
 *epr_path = *Net::SAMLc::zxid_epr_path;
 *get_epr = *Net::SAMLc::zxid_get_epr;
@@ -850,6 +857,8 @@ use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
 *swig_a7nttl_set = *Net::SAMLc::zxid_conf_a7nttl_set;
 *swig_pdp_url_get = *Net::SAMLc::zxid_conf_pdp_url_get;
 *swig_pdp_url_set = *Net::SAMLc::zxid_conf_pdp_url_set;
+*swig_pdp_call_url_get = *Net::SAMLc::zxid_conf_pdp_call_url_get;
+*swig_pdp_call_url_set = *Net::SAMLc::zxid_conf_pdp_call_url_set;
 *swig_need_get = *Net::SAMLc::zxid_conf_need_get;
 *swig_need_set = *Net::SAMLc::zxid_conf_need_set;
 *swig_want_get = *Net::SAMLc::zxid_conf_want_get;
